@@ -59,12 +59,20 @@ class CommonConstant:
      * 1-免费
      * 2-仅支持会员包售卖
      * 3-同时支持单课程售卖和会员包售卖
+     * 4-只支持教育中心会员售卖
+     * 5-同时支持教育中心会员售卖和单卖
+     * 6-同时支持教育中心会员售卖和CP会员售卖
+     * 7-同时支持教育中心会员售卖和CP会员售卖和单卖  
     """
     COURSE_SELLING_MODE = {
         'SEPARATELY': 0,
         'FREE': 1,
         'SOLD_BY_PACKAGE_ONLY': 2,
-        'SOLD_SEPARATELY_AND_BY_PACKAGE': 3
+        'SOLD_SEPARATELY_AND_BY_PACKAGE': 3,
+        'SOLD_BY_EDUCATION_ONLY': 4,
+        'SOLD_SEPARATELY_AND_BY_EDUCATION': 5,
+        'SOLD_EDUCATION_AND_BY_CP': 6,
+        'SOLD_SEPARATELY_AND_BY_CP_AND_BY_EDUCATION': 7
     }
     """
      有效期单位
@@ -85,9 +93,11 @@ class CommonConstant:
      课程类型
      * 1000-其它类型
      * 1001-直播课
-     * 1002-录播课
-     * 1003-教辅教材
+     * 1002-视频课
+     * 1003-教材
      * 1004-绘本
+     * 1005-教辅
+     * 1006-音频
     """
     COURSE_TYPE = {
         'OTHERS': 1000,
@@ -95,6 +105,8 @@ class CommonConstant:
         'RECORDED': 1002,
         'TEACHING_MATERIALS': 1003,
         'DRAWING_BOOK': 1004,
+        'TUTORS': 1005,
+        'AUDIO': 1006
     }
     """
      订购状态
@@ -116,13 +128,6 @@ class CommonConstant:
     """
     COURSE_LESSON_MEDIA_TYPE = {'AUDIO': 1, 'VIDEO': 2, 'DRAWING_BOOK': 3}
 
-    CREDENTIAL_LIST = {
-        'client_id': '235889897037149184',
-        'client_secret': '55A5C9CA1E983328DA7E020B'
-        '1A1CC4B02AEB80BFF60F648F74997670D45C7EFF',
-        'grant_type': 'client_credentials'
-    }
-
     CONFIG_DIR = 'config'
     AUTH_DIR = 'ssl'
     LOG_DIR = os.path.join('storage', 'log')
