@@ -435,9 +435,6 @@ class CourseHandler:
         update_media_localized_data = UpdateMediaLocalizedData()
         update_media_localized_data.media_type = \
             media_localized_data.media_type
-        update_media_localized_data.height = media_localized_data.height
-        update_media_localized_data.width = media_localized_data.width
-        update_media_localized_data.media_len = media_localized_data.media_len
         update_media_localized_data.ordinal = media_localized_data.ordinal
 
         upload_frame_img_result = self._upload_frame_image(
@@ -469,7 +466,7 @@ class CourseHandler:
             file_upload = FileUpload(
                 path=course_localized_data.cover_image_file_info.path,
                 resource_type=FileUploadConstant.RESOURCE_TYPE[
-                    CourseConstant.COURSE_PACKAGE_HORIZONTAL_COVER],
+                    CourseConstant.COURSE_LESSON_PACKAGE_HORIZONTAL_COVER],
                 request_sender=self._request_sender)
             result = file_upload.upload()
         except EduKitException as e:
