@@ -12,6 +12,9 @@ from edukit_sdk.edukit.common.exception.edu_kit_exception import \
     EduKitException
 from edukit_sdk.edukit.common.errorcode.common_error_code import \
     CommonErrorCode
+from edukit_sdk.edukit.common.constant.file_upload_constant import \
+    FileUploadConstant
+from edukit_sdk.edukit.common.file_upload.file_upload import FileUpload
 from edukit_sdk.edukit.lesson.model.lesson import Lesson
 from edukit_sdk.edukit.common.helpers.helpers import Helpers
 from edukit_sdk.edukit.common.http.edu_kit_request_sender import \
@@ -35,6 +38,10 @@ from edukit_sdk.edukit.lesson.resp.lesson_create_response import \
     LessonCreateResponse
 from edukit_sdk.edukit.lesson.resp.lesson_update_response import \
     LessonUpdateResponse
+from edukit_sdk.edukit.lesson.model.lesson_localized_data import \
+    LessonLocalizedData
+from edukit_sdk.edukit.lesson.model.lesson_edit_localized_data import \
+    LessonEditLocalizedData
 
 
 class LessonHandler:
@@ -225,8 +232,11 @@ class LessonHandler:
         response.result = Helpers.build_error_result(CommonErrorCode.SUCCESS)
         for item in lesson.multi_lang_localized_data_list:
             update_localized_data_request = UpdateLocalizedDataRequest()
-            update_localized_data_request.localized_data = \
-                item.lesson_localized_data
+            if item and item.lesson_localized_data:
+                localized_data_result = self._upload_localized_data(
+                    item.lesson_localized_data)
+                update_localized_data_request.localized_data = \
+                    localized_data_result
             if item.media_localized_data:
                 update_localized_media_result_list = list()
                 single_result = UpdateDataUtil.update_multi_language_data(
@@ -422,3 +432,42 @@ class LessonHandler:
                 lesson_id,
             ))
         return response
+
+    def _upload_localized_data(
+            self, lesson_localized_data: LessonLocalizedData):
+        localized_edit_localize_data = LessonEditLocalizedData()
+        localized_edit_localize_data.name = lesson_localized_data.name
+        localized_edit_localize_data.deeplink_url = \
+            lesson_localized_data.deeplink_url
+
+        upload_cover_img_result = self._upload_cover_image(
+            lesson_localized_data)
+        if not upload_cover_img_result:
+            return False
+        if isinstance(upload_cover_img_result, str):
+            localized_edit_localize_data.cover_id = upload_cover_img_result
+
+        return localized_edit_localize_data
+
+    def _upload_cover_image(self, lesson_localized_data: LessonLocalizedData):
+        if not lesson_localized_data.cover_image_file_info:
+            return True
+        try:
+            file_upload = FileUpload(
+                path=lesson_localized_data.cover_image_file_info.path,
+                resource_type=FileUploadConstant.RESOURCE_TYPE[
+                    'COURSE_LESSON_PACKAGE_HORIZONTAL_COVER'],
+                request_sender=self._request_sender)
+            result = file_upload.upload()
+        except EduKitException as e:
+            logging.error('Upload cover image failed. errMsg:%s' %
+                          e.message)
+            return False
+
+        if not Helpers.is_success(result):
+            logging.error('Upload cover image failed. errMsg:%s' %
+                          result.get(LessonConstant.RESULT).get(
+                              LessonConstant.RESULT_DESC))
+            return False
+
+        return result.get('materialId')
